summaryrefslogtreecommitdiff
path: root/include/drawinglayer/primitive2d/baseprimitive2d.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'include/drawinglayer/primitive2d/baseprimitive2d.hxx')
-rw-r--r--include/drawinglayer/primitive2d/baseprimitive2d.hxx8
1 files changed, 4 insertions, 4 deletions
diff --git a/include/drawinglayer/primitive2d/baseprimitive2d.hxx b/include/drawinglayer/primitive2d/baseprimitive2d.hxx
index 157c13bb33a8..4ff639680248 100644
--- a/include/drawinglayer/primitive2d/baseprimitive2d.hxx
+++ b/include/drawinglayer/primitive2d/baseprimitive2d.hxx
@@ -29,16 +29,16 @@
#include <basegfx/range/b2drange.hxx>
//////////////////////////////////////////////////////////////////////////////
/** defines for DeclPrimitrive2DIDBlock and ImplPrimitrive2DIDBlock
Added to be able to simply change identification stuff later, e.g. add
a identification string and/or ID to the interface and to the implementation
ATM used to delclare implement getPrimitive2DID()
*/
-#define DeclPrimitrive2DIDBlock() \
+#define DeclPrimitive2DIDBlock() \
virtual sal_uInt32 getPrimitive2DID() const;
-#define ImplPrimitrive2DIDBlock(TheClass, TheID) \
+#define ImplPrimitive2DIDBlock(TheClass, TheID) \
sal_uInt32 TheClass::getPrimitive2DID() const { return TheID; }
//////////////////////////////////////////////////////////////////////////////
@@ -160,7 +160,7 @@ namespace drawinglayer
/** provide unique ID for fast identifying of known primitive implementations in renderers. These use
the defines from drawinglayer_primitivetypes2d.hxx to define unique IDs.
- This method is normally defined using DeclPrimitrive2DIDBlock()
+ This method is normally defined using DeclPrimitive2DIDBlock()
*/
virtual sal_uInt32 getPrimitive2DID() const = 0;
@@ -29,16 +29,16 @@
#include <basegfx/range/b2drange.hxx>
//////////////////////////////////////////////////////////////////////////////
-/** defines for DeclPrimitrive2DIDBlock and ImplPrimitrive2DIDBlock
+/** defines for DeclPrimitive2DIDBlock and ImplPrimitive2DIDBlock
Added to be able to simply change identification stuff later, e.g. add
a identification string and/or ID to the interface and to the implementation